@@ -20,19 +20,20 @@ import random
 import string
 import uuid
 from collections import namedtuple
-
+import ast
 import gevent
 import gevent.lock
 import zmq.green as zmq
-from flask import Flask, render_template, request, redirect, flash, Response, abort
+from flask import Flask, render_template, redirect, flash, Response, abort
 from flask.ext.login import LoginManager, login_user, current_user, login_required, logout_user
 from sqlalchemy.orm.exc import NoResultFound
 from sqlalchemy import desc
 from werkzeug.security import check_password_hash
 from wtforms import HiddenField
+from flask import request
 
 from beeswarm.server.webapp.auth import Authenticator
-from forms import HoneypotConfigurationForm, NewClientConfigForm, LoginForm, SettingsForm
+from forms import HoneypotConfigurationForm, ClientConfigurationForm, LoginForm, SettingsForm
 from beeswarm.server.db import database_setup
 from beeswarm.server.db.entities import Client, BaitSession, Session, Honeypot, User, BaitUser, Transcript, Drone, \
     Authentication
@@ -297,8 +298,67 @@ def configure_client(id):
     drone = db_session.query(Drone).filter(Drone.id == id).one()
     if drone.discriminator != 'client' or drone is None:
         abort(404, 'Drone with id {0} not found or invalid.'.format(id))
-    send_config_request('{0} {1}'.format(Messages.DRONE_CONFIG_CHANGED, drone.id))
-    return render_template('finish-config-client.html', drone_id=drone.id, user=current_user)
+    config_dict = send_config_request('{0} {1}'.format(Messages.DRONE_CONFIG, id))
+    config_obj = DictWrapper(config_dict)
+    form = ClientConfigurationForm(obj=config_obj)
+    if not form.validate_on_submit():
+        return render_template('configure-client.html', form=form, mode_name='Client', user=current_user)
+    else:
+        bait_timing_config = {
+            'http': {
+                'active_range': form.bait_timings__http__active_range.data,
+                'sleep_interval': form.bait_timings__http__sleep_interval.data,
+                'activation_probability': form.bait_timings__http__activation_probability.data
+            },
+            'ftp': {
+                'active_range': form.bait_timings__ftp__active_range.data,
+                'sleep_interval': form.bait_timings__ftp__sleep_interval.data,
+                'activation_probability': form.bait_timings__ftp__activation_probability.data
+            },
+            'https': {
+                'active_range': form.bait_timings__https__active_range.data,
+                'sleep_interval': form.bait_timings__https__sleep_interval.data,
+                'activation_probability': form.bait_timings__https__activation_probability.data
+            },
+            'pop3': {
+                'active_range': form.bait_timings__pop3__active_range.data,
+                'sleep_interval': form.bait_timings__pop3__sleep_interval.data,
+                'activation_probability': form.bait_timings__pop3__activation_probability.data
+            },
+            'ssh': {
+                'active_range': form.bait_timings__ssh__active_range.data,
+                'sleep_interval': form.bait_timings__ssh__sleep_interval.data,
+                'activation_probability': form.bait_timings__ssh__activation_probability.data
+            },
+            'pop3s': {
+                'active_range': form.bait_timings__pop3s__active_range.data,
+                'sleep_interval': form.bait_timings__pop3s__sleep_interval.data,
+                'activation_probability': form.bait_timings__pop3s__activation_probability.data
+            },
+            'smtp': {
+                'active_range': form.bait_timings__smtp__active_range.data,
+                'sleep_interval': form.bait_timings__smtp__sleep_interval.data,
+                'activation_probability': form.bait_timings__smtp__activation_probability.data
+            },
+            'vnc': {
+                'active_range': form.bait_timings__vnc__active_range.data,
+                'sleep_interval': form.bait_timings__vnc__sleep_interval.data,
+                'activation_probability': form.bait_timings__vnc__activation_probability.data
+            },
+            'telnet': {
+                'active_range': form.bait_timings__telnet__active_range.data,
+                'sleep_interval': form.bait_timings__telnet__sleep_interval.data,
+                'activation_probability': form.bait_timings__telnet__activation_probability.data
+            }
+        }
+
+        drone.bait_timings = json.dumps(bait_timing_config)
+        db_session.add(drone)
+        db_session.commit()
+
+        send_config_request('{0} {1}'.format(Messages.DRONE_CONFIG_CHANGED, drone.id))
+        return render_template('finish-config-client.html', drone_id=drone.id, user=current_user)
+
 
 
 @app.route('/ws/drone/configure/<id>', methods=['GET', 'POST'])
@@ -564,30 +624,20 @@ def logout():
 @app.route('/settings', methods=['GET', 'POST'])
 @login_required
 def settings():
-    global config
-    # we need getattr for WTF
-    formdata = namedtuple('Struct', config.keys())(*config.values())
     bait_session_retain = send_config_request('{0} {1}'.format(Messages.GET_CONFIG_ITEM, 'bait_session_retain'))
-    form = SettingsForm(obj=formdata, bait_session_retain=bait_session_retain)
+    ignore_failed_bait_session = ast.literal_eval(send_config_request('{0} {1}'.format(Messages.GET_CONFIG_ITEM, 'ignore_failed_bait_session')))
+    malicious_session_retain = send_config_request('{0} {1}'.format(Messages.GET_CONFIG_ITEM, 'malicious_session_retain'))
+    form = SettingsForm(bait_session_retain=bait_session_retain, malicious_session_retain=malicious_session_retain,
+                        ignore_failed_bait_session=ignore_failed_bait_session)
 
     if form.validate_on_submit():
         # the potential updates that we want to save to config file.
         options = {'bait_session_retain': form.bait_session_retain.data,
                    'malicious_session_retain': form.malicious_session_retain.data,
                    'ignore_failed_bait_session': form.ignore_failed_bait_session.data}
-        update_config(options)
+        send_config_request('{0} {1}'.format(Messages.SET_CONFIG_ITEM, json.dumps(options)))
     return render_template('settings.html', form=form, user=current_user)
 
 
-def update_config(options):
-    context = beeswarm.shared.zmq_context
-    socket = context.socket(zmq.REQ)
-    socket.connect('inproc://configCommands')
-    socket.send('{0} {1}'.format(Messages.SET_CONFIG_ITEM, json.dumps(options)))
-    reply = socket.recv()
-    if reply != Messages.OK:
-        logger.warning('Error while requesting config change to actor.')
-    socket.close()
-
 if __name__ == '__main__':
     app.run()
