@@ -13,14 +13,14 @@ class Messages(Enum):
 
     OK = 'OK'
     FAIL = 'FAIL'
-    PUBLISH_CONFIG = 'PUBLISH_CONFIG'
     # KEY DRONE_ID DRONE_PRIVATE_KEY
     KEY = 'KEY'
     # CERT DRONE_ID DRONE_CERT
     CERT = 'CERT'
     SESSION_HONEYPOT = 'SESSION_HONEYPOT'
     SESSION_CLIENT = 'SESSION_CLIENT'
-    SET = 'SET'
+    SET_CONFIG_ITEM = 'SET'
+    GET_CONFIG_ITEM = 'GET'
     GEN_ZMQ_KEYS = 'GEN_ZMQ_KEYS'
     PING = 'PING'
     PONG = 'PING'
